tobiko.conf
-----------

Tobiko will look for configuration files at below paths:

- /etc/tobiko/tobiko.conf
- ./tobiko.conf

The format of the file is the same as other `OpenStack *.conf ini files
<https://docs.openstack.org/oslo.config/latest/configuration/format.html>`_.

This section provides a list of all configuration options for
tobiko.conf file. It is being auto-generated from Tobiko code when
this documentation is being built.

It can also be viewed in `raw format <../_static/tobiko.conf.txt>`_.

.. literalinclude:: ../_static/tobiko.conf.sample
